import{_ as f}from"./Navbar.vue_vue_type_script_setup_true_lang.4efe169c.js";import{g as p}from"./api.4873ae96.js";import{a as _}from"./asyncComputed.21831dee.js";import{W as y}from"./WidgetsFrame.f3e18a8a.js";import{d as g,eB as b,b as n,ev as h,e as a,u as t,c as m,w as v,ex as l,eD as u,v as w}from"./outputWidgets.6bfc0239.js";import"./index.d59ef797.js";import"./pubsub.56f48661.js";import"./index.a0291250.js";import"./ArrowRightOutlined.08fa31dd.js";import"./Base.3f4f4c87.js";import"./Typography.7fe49268.js";import"./Text.3be64ce1.js";import"./runnerData.218d57bf.js";import"./url.c2408bab.js";(function(){try{var o=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},r=new D().stack;r&&(o._sentryDebugIds=o._sentryDebugIds||{},o._sentryDebugIds[r]="c182dd4c-1d5b-4c59-ae82-11c6432d9b29",o._sentryDebugIdIdentifier="sentry-dbid-c182dd4c-1d5b-4c59-ae82-11c6432d9b29")}catch{}})();const k={class:"error"},I={class:"inner-content"},x=g({__name:"Error",setup(o){const r=b(),{result:e}=_(p),c=()=>{const{status:s}=r.params;switch(s){case"404":return{status:s,message:"Page not found."};case"403":return{status:s,message:"Access denied. Please contact your administrator."};default:return{status:"500",message:"An unknown error ocurred. Please try again or contact support."}}};return(s,B)=>(n(),h("div",null,[a("div",k,[t(e)?(n(),m(y,{key:0,"main-color":t(e).mainColor,theme:t(e).theme,"font-family":t(e).fontFamily,style:{height:"100vh"}},{default:v(()=>{var d,i;return[t(e)?(n(),m(f,{key:0,"brand-name":((d=t(e))==null?void 0:d.brandName)||((i=t(e))==null?void 0:i.name),"logo-url":t(e).logoUrl},null,8,["brand-name","logo-url"])):l("",!0),a("div",I,[a("h1",null,u(c().status),1),a("p",null,u(c().message),1)])]}),_:1},8,["main-color","theme","font-family"])):l("",!0)])]))}});const D=w(x,[["__scopeId","data-v-befb94cf"]]);export{D as default};
//# sourceMappingURL=Error.ee20904a.js.map
