import{V as s,f as p,Q as d}from"./outputWidgets.6bfc0239.js";import{B as f,b as c}from"./Base.3f4f4c87.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},a=new Error().stack;a&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[a]="973cae4c-8163-41fd-b93e-3fc6bee6a4d4",e._sentryDebugIdIdentifier="sentry-dbid-973cae4c-8163-41fd-b93e-3fc6bee6a4d4")}catch{}})();const i=()=>d(c(),["component"]),r=(e,a)=>{let{slots:t,attrs:o}=a;const n=s(s(s({},e),{component:"div"}),o);return p(f,n,t)};r.displayName="ATypographyParagraph";r.inheritAttrs=!1;r.props=i();const g=r;export{g as A};
//# sourceMappingURL=Paragraph.100fbd75.js.map
