import{B as s}from"./Base.3f4f4c87.js";import{A as o}from"./Link.c1cadb68.js";import{A as r}from"./Paragraph.100fbd75.js";import{A as a}from"./Text.3be64ce1.js";import{A as i}from"./Title.84d6428e.js";import{T as e}from"./Typography.7fe49268.js";(function(){try{var n=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(n._sentryDebugIds=n._sentryDebugIds||{},n._sentryDebugIds[t]="4cb66be8-c262-4757-b195-031c8969015c",n._sentryDebugIdIdentifier="sentry-dbid-4cb66be8-c262-4757-b195-031c8969015c")}catch{}})();e.Text=a;e.Title=i;e.Paragraph=r;e.Link=o;e.Base=s;e.install=function(n){return n.component(e.name,e),n.component(e.Text.displayName,a),n.component(e.Title.displayName,i),n.component(e.Paragraph.displayName,r),n.component(e.Link.displayName,o),n};
//# sourceMappingURL=index.6bbf489e.js.map
