import{u as s}from"./index.d59ef797.js";import{d as c,b as d,ev as f,f as p,u as r}from"./outputWidgets.6bfc0239.js";import{g as l}from"./api.4873ae96.js";import{K as u,L as b}from"./repository.03c973cb.js";import{_ as g}from"./Navbar.vue_vue_type_script_setup_true_lang.4efe169c.js";import{a as y}from"./asyncComputed.21831dee.js";import{P as _}from"./repository.dc59ddc1.js";import"./pubsub.56f48661.js";import"./runnerData.218d57bf.js";import"./url.c2408bab.js";import"./api.301ca4a6.js";import"./index.cf4c23b9.js";import"./icons.5f4f8713.js";import"./ant-design.bf757549.js";import"./index.71301f31.js";import"./Modal.9595e4e0.js";import"./Text.3be64ce1.js";import"./Base.3f4f4c87.js";import"./Typography.7fe49268.js";import"./index.6bbf489e.js";import"./Link.c1cadb68.js";import"./Paragraph.100fbd75.js";import"./Title.84d6428e.js";import"./index.60dad040.js";import"./index.ecc37a00.js";import"./index.8802c5fa.js";import"./index.567ffd31.js";import"./CollapsePanel.3dd38c7f.js";import"./Form.7d1a8597.js";import"./hasIn.42df2c7d.js";import"./Timeline.049ef2a2.js";import"./index.81e0c92a.js";import"./index.9753d7a2.js";import"./isNumeric.75337b1e.js";import"./contracts.generated.7a08d10a.js";import"./workspaces.aee677ed.js";import"./record.dbb754fe.js";import"./scripts.cd1bef2a.js";import"./envVars.75d5e3af.js";import"./ExpandOutlined.3c2528f9.js";import"./Card.77a4a6f5.js";import"./TabPane.e27b42bc.js";import"./index.a0291250.js";import"./ArrowRightOutlined.08fa31dd.js";(function(){try{var o=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(o._sentryDebugIds=o._sentryDebugIds||{},o._sentryDebugIds[t]="40c0c63f-dce6-4e70-9364-452600b7c9a2",o._sentryDebugIdIdentifier="sentry-dbid-40c0c63f-dce6-4e70-9364-452600b7c9a2")}catch{}})();const fo=c({__name:"Kanban",setup(o){const t=new _(s),a=new b("kanban"),{result:e}=y(l);return(k,w)=>{var i,m,n;return d(),f("div",null,[p(g,{"brand-name":((i=r(e))==null?void 0:i.brandName)||((m=r(e))==null?void 0:m.name),"logo-url":(n=r(e))==null?void 0:n.logoUrl},null,8,["brand-name","logo-url"]),p(u,{"kanban-repository":r(t),storage:r(a)},null,8,["kanban-repository","storage"])])}}});export{fo as default};
//# sourceMappingURL=Kanban.b2b65d30.js.map
