.terminal[data-v-032cbeba]{margin-top:20px;width:96%;background-color:#212427;padding:12px 16px;border-radius:8px;overflow:scroll}.log-text[data-v-032cbeba]{color:#fff;margin:4px}.panel[data-v-e10d3de6] .ant-collapse-header{padding:0}.stages-container[data-v-2a074c8a]{max-width:100vw;position:relative;flex-grow:1}.stages-container .stages-content[data-v-2a074c8a]{padding:20px;overflow:auto}.stages-container .stages-content[data-v-2a074c8a] .ant-select-selection-item{display:flex;align-items:center}
