(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},f=new Error().stack;f&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[f]="7cfe177f-b8d8-4ffc-aa59-656cffed33af",e._sentryDebugIdIdentifier="sentry-dbid-7cfe177f-b8d8-4ffc-aa59-656cffed33af")}catch{}})();const n=e=>!isNaN(parseFloat(e))&&isFinite(e),s=n;export{s as i};
//# sourceMappingURL=isNumeric.75337b1e.js.map
