import{v as t,b as s,ev as o}from"./outputWidgets.6bfc0239.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},n=new Error().stack;n&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[n]="a02e5c53-ee79-472d-96a4-8630bcf98549",e._sentryDebugIdIdentifier="sentry-dbid-a02e5c53-ee79-472d-96a4-8630bcf98549")}catch{}})();const r={},a={class:"organization-settings"};function i(e,n){return s(),o("div",a,"Organization settings")}const f=t(r,[["render",i]]);export{f as default};
//# sourceMappingURL=OrganizationSettings.321cc120.js.map
