import"./outputWidgets.6bfc0239.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="d43249fb-4418-4e0c-aa5e-ce6f6e43acff",e._sentryDebugIdIdentifier="sentry-dbid-d43249fb-4418-4e0c-aa5e-ce6f6e43acff")}catch{}})();function n(e,t){return e.toLocaleString(void 0,{hour12:!1,timeZoneName:"short",day:"2-digit",month:"2-digit",year:"numeric",hour:"2-digit",minute:"2-digit",second:"2-digit",weekday:"long",...t})}export{n as g};
//# sourceMappingURL=datetime.c7b3e9c3.js.map
