import{r as a,w as r}from"./runnerData.218d57bf.js";import"./outputWidgets.6bfc0239.js";(function(){try{var t=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},e=new Error().stack;e&&(t._sentryDebugIds=t._sentryDebugIds||{},t._sentryDebugIds[e]="00dc0309-6ef3-4169-a918-401837ca10d2",t._sentryDebugIdIdentifier="sentry-dbid-00dc0309-6ef3-4169-a918-401837ca10d2")}catch{}})();async function f(t){const e=await fetch(`/_pages/${t}`);if(e.status==404)return null;if(!e.ok)throw new Error(await e.text());const{form:n}=await e.json();return n?a(n):null}async function u(){const t=await fetch("/_workspace");if(t.status!=200)return r({});const e=await t.json();return r(e)}export{f,u as g};
//# sourceMappingURL=api.4873ae96.js.map
