import{d as m,eB as c,u as e,b as d,c as u,ev as y,f as o,w as a,bv as _,ar as p,ex as g,e as b,eD as x}from"./outputWidgets.6bfc0239.js";import"./router.979769f7.js";import"./index.76d87691.js";import{O as w}from"./organization.721b781f.js";import{a as k}from"./asyncComputed.21831dee.js";import{A}from"./Title.84d6428e.js";import{A as B}from"./index.60dad040.js";import{A as h}from"./index.81e0c92a.js";import{A as C}from"./Text.3be64ce1.js";import{C as v}from"./Card.77a4a6f5.js";import"./Form.7d1a8597.js";import"./hasIn.42df2c7d.js";import"./index.cf4c23b9.js";import"./record.dbb754fe.js";import"./pubsub.56f48661.js";import"./Base.3f4f4c87.js";import"./Typography.7fe49268.js";import"./TabPane.e27b42bc.js";(function(){try{var t=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},r=new Error().stack;r&&(t._sentryDebugIds=t._sentryDebugIds||{},t._sentryDebugIds[r]="792d0edc-5d3f-46d4-b332-afd1e254e175",t._sentryDebugIdIdentifier="sentry-dbid-792d0edc-5d3f-46d4-b332-afd1e254e175")}catch{}})();const D={key:1},I={style:{display:"flex","justify-content":"flex-end","font-size":"24px"}},W=m({__name:"Billing",setup(t){const n=c().params.organizationId,{loading:l,result:f}=k(()=>w.get(n));return(z,N)=>e(l)?(d(),u(e(_),{key:0})):(d(),y("div",D,[o(e(B),{justify:"space-between",align:"center"},{default:a(()=>[o(e(A),{level:3},{default:a(()=>[p("Current plan")]),_:1}),g("",!0)]),_:1}),o(e(h),{style:{"margin-top":"0"}}),o(e(v),{style:{width:"300px"}},{default:a(()=>{var i,s;return[o(e(C),{type:"secondary"},{default:a(()=>[p("Plan")]),_:1}),b("div",I,x((s=(i=e(f))==null?void 0:i.billingMetadata)==null?void 0:s.plan),1)]}),_:1})]))}});export{W as default};
//# sourceMappingURL=Billing.15e36117.js.map
