import{v as r,a as i,b as a,c,j as d,T as p,k as _,P as u,C as f,M as l,s as g,l as s,m,n as y,p as b,q as v}from"./outputWidgets.6bfc0239.js";import{s as w,a as o}from"./index.d59ef797.js";import"./pubsub.56f48661.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="718bfd16-fc36-4a22-9c59-e8976140cc81",e._sentryDebugIdIdentifier="sentry-dbid-718bfd16-fc36-4a22-9c59-e8976140cc81")}catch{}})();const h={};function I(e,t){const n=i("router-view");return a(),c(n,{style:{"min-height":"100vh","box-sizing":"border-box",width:"100%"}})}const k=r(h,[["render",I]]);class x{static init(){setInterval(()=>fetch("/_version"),20*1e3)}}(async()=>{await w();const e=d({render:()=>m(k)});p.init(),_(e,o),x.init(),e.use(o),e.use(u),e.mount("#app"),e.component("VSelect",f),e.component("Markdown",l),e.component("Message",g),s(e,y),s(e,b),s(e,v)})();
//# sourceMappingURL=player.26778a0f.js.map
