import{e8 as p,ac as c,V as s,f as y,Q as b}from"./outputWidgets.6bfc0239.js";import{B as d,b as u}from"./Base.3f4f4c87.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},o=new Error().stack;o&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[o]="b110a725-968a-433a-9536-f599a79fc616",e._sentryDebugIdIdentifier="sentry-dbid-b110a725-968a-433a-9536-f599a79fc616")}catch{}})();var g=globalThis&&globalThis.__rest||function(e,o){var n={};for(var t in e)Object.prototype.hasOwnProperty.call(e,t)&&o.indexOf(t)<0&&(n[t]=e[t]);if(e!=null&&typeof Object.getOwnPropertySymbols=="function")for(var r=0,t=Object.getOwnPropertySymbols(e);r<t.length;r++)o.indexOf(t[r])<0&&Object.prototype.propertyIsEnumerable.call(e,t[r])&&(n[t[r]]=e[t[r]]);return n};const m=p(1,2,3,4,5),_=()=>s(s({},b(u(),["component","strong"])),{level:Number}),a=(e,o)=>{let{slots:n,attrs:t}=o;const{level:r=1}=e,f=g(e,["level"]);let l;m.includes(r)?l=`h${r}`:(c(),l="h1");const i=s(s(s({},f),{component:l}),t);return y(d,i,n)};a.displayName="ATypographyTitle";a.inheritAttrs=!1;a.props=_();const w=a;export{w as A};
//# sourceMappingURL=Title.84d6428e.js.map
