import{V as a,ac as c,f as d,Q as y}from"./outputWidgets.6bfc0239.js";import{B as b,b as u}from"./Base.3f4f4c87.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},n=new Error().stack;n&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[n]="c70f568f-c824-450a-a5ec-2ba487141cae",e._sentryDebugIdIdentifier="sentry-dbid-c70f568f-c824-450a-a5ec-2ba487141cae")}catch{}})();var g=globalThis&&globalThis.__rest||function(e,n){var o={};for(var t in e)Object.prototype.hasOwnProperty.call(e,t)&&n.indexOf(t)<0&&(o[t]=e[t]);if(e!=null&&typeof Object.getOwnPropertySymbols=="function")for(var r=0,t=Object.getOwnPropertySymbols(e);r<t.length;r++)n.indexOf(t[r])<0&&Object.prototype.propertyIsEnumerable.call(e,t[r])&&(o[t[r]]=e[t[r]]);return o};const m=()=>y(a(a({},u()),{ellipsis:{type:Boolean,default:void 0}}),["component"]),s=(e,n)=>{let{slots:o,attrs:t}=n;const r=a(a({},e),t),{ellipsis:p,rel:l}=r,i=g(r,["ellipsis","rel"]);c();const f=a(a({},i),{rel:l===void 0&&i.target==="_blank"?"noopener noreferrer":l,ellipsis:!!p,component:"a"});return delete f.navigate,d(b,f,o)};s.displayName="ATypographyLink";s.inheritAttrs=!1;s.props=m();const O=s;export{O as A};
//# sourceMappingURL=Link.c1cadb68.js.map
