import{ac as i,V as t,Q as a,f as b}from"./outputWidgets.6bfc0239.js";import{B as c,b as p}from"./Base.3f4f4c87.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},s=new Error().stack;s&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[s]="cd0f90d0-c5ad-4bde-bcf4-bb2b89f69285",e._sentryDebugIdIdentifier="sentry-dbid-cd0f90d0-c5ad-4bde-bcf4-bb2b89f69285")}catch{}})();const l=()=>t(t({},a(p(),["component"])),{ellipsis:{type:[Boolean,Object],default:void 0}}),o=(e,s)=>{let{slots:d,attrs:r}=s;const{ellipsis:n}=e;i();const f=t(t(t({},e),{ellipsis:n&&typeof n=="object"?a(n,["expandable","rows"]):n,component:"span"}),r);return b(c,f,d)};o.displayName="ATypographyText";o.inheritAttrs=!1;o.props=l();const g=o;export{g as A};
//# sourceMappingURL=Text.3be64ce1.js.map
