import{d as w,eA as A,eB as B,r as h,H as D,b as t,c as d,w as a,ev as i,eC as v,u as n,cx as N,a$ as y,bu as $,f as o,ez as L,I as m,ar as V,eD as E,ex as g,bw as R,v as k,eE as T,eF as M,e as x,a as q}from"./outputWidgets.6bfc0239.js";import{p as z,w as F,k as H,s as P,a as W,b as j,v as G,c as J,d as K}from"./icons.5f4f8713.js";import{_ as O}from"./logo.084e5d7c.js";import{B as Q}from"./BaseLayout.b05ffc6b.js";import{N as U}from"./NavbarControls.dfb9a068.js";import{c as X}from"./index.a0291250.js";import"./workspaces.aee677ed.js";import"./runnerData.218d57bf.js";import"./url.c2408bab.js";import"./record.dbb754fe.js";import"./pubsub.56f48661.js";import"./asyncComputed.21831dee.js";import"./envVars.75d5e3af.js";import"./index.d59ef797.js";import"./SaveButton.vue_vue_type_script_setup_true_lang.b3ad499f.js";import"./ant-design.bf757549.js";import"./index.71301f31.js";import"./Modal.9595e4e0.js";import"./Typography.7fe49268.js";import"./Link.c1cadb68.js";import"./Base.3f4f4c87.js";import"./index.eba2f742.js";import"./popupNotifcation.9ba9d802.js";import"./index.60dad040.js";import"./Text.3be64ce1.js";import"./DocsButton.vue_vue_type_script_setup_true_lang.77240f7b.js";import"./Paragraph.100fbd75.js";import"./ArrowRightOutlined.08fa31dd.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},s=new Error().stack;s&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[s]="bd4bd1d3-7349-4b77-9ba7-e5f9b0d57a91",e._sentryDebugIdIdentifier="sentry-dbid-bd4bd1d3-7349-4b77-9ba7-e5f9b0d57a91")}catch{}})();const Y={key:0,class:"collapsible"},Z={key:1,class:"collapsible"},ee=w({__name:"Sidebar",setup(e){var f;const s=A(),p=B(),l=h((f=p.name)!=null?f:"forms"),r=h(!1),b=()=>{r.value=!r.value},C=D(()=>[{name:"Project",children:[{name:"Stages",icon:z,path:"stages"},{name:"Workflow",icon:F,path:"workflow"},{name:"Threads",icon:H,path:"kanban"}]},{name:"Settings",children:[{name:"Style",icon:P,path:"style"},{name:"Sidebar",icon:W,path:"sidebar"},{name:"Requirements",icon:j,path:"requirements"},{name:"Env Vars",icon:G,path:"env-vars"}]}]),S=_=>{s.push(_.path),l.value=_.path};return(_,le)=>(t(),d(n(R),{"inline-collapsed":r.value,style:{display:"flex","flex-direction":"column"}},{default:a(()=>[(t(!0),i(y,null,v(C.value,u=>(t(),d(n(N),{key:u.name,title:u.name},{default:a(()=>[(t(!0),i(y,null,v(u.children,c=>(t(),d(n($),{key:c.name,role:"button",tabindex:"0",onClick:de=>S(c)},{icon:a(()=>[o(m,{class:L({active:l.value===c.path}),path:c.icon,width:"18",height:"18"},null,8,["class","path"])]),default:a(()=>[V(E(c.name),1)]),_:2},1032,["onClick"]))),128))]),_:2},1032,["title"]))),128)),r.value?(t(),i("div",Y,[o(m,{path:n(J),onClick:b},null,8,["path"])])):g("",!0),r.value?g("",!0):(t(),i("div",Z,[o(m,{path:n(K),onClick:b},null,8,["path"])]))]),_:1},8,["inline-collapsed"]))}});const te=k(ee,[["__scopeId","data-v-4aaf506f"]]);const ae={},I=e=>(T("data-v-81cd596e"),e=e(),M(),e),oe={class:"logo"},se=I(()=>x("img",{src:O,alt:"Abstra cloud logo"},null,-1)),ne=I(()=>x("span",null," Abstra ",-1)),re=[se,ne];function ce(e,s){return t(),i("div",oe,re)}const ie=k(ae,[["render",ce],["__scopeId","data-v-81cd596e"]]),ze=w({__name:"Workspace",setup(e){return(s,p)=>{const l=q("router-view");return t(),d(Q,{"full-canvas":""},{navbar:a(()=>[o(n(X),{style:{padding:"5px 25px"}},{title:a(()=>[o(ie)]),extra:a(()=>[o(U,{"show-github-stars":"","show-v-s-code-button":""})]),_:1})]),sidebar:a(()=>[o(te,{class:"sidebar"})]),content:a(()=>[o(l)]),_:1})}}});export{ze as default};
//# sourceMappingURL=Workspace.cbf76994.js.map
