import{C as t,A as m}from"./CollapsePanel.3dd38c7f.js";import{F as n}from"./Form.7d1a8597.js";import{aM as i,co as r}from"./outputWidgets.6bfc0239.js";import{T as o,A as s}from"./Timeline.049ef2a2.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},a=new Error().stack;a&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[a]="bc27de8f-9be7-4730-a671-77f0da8d662c",e._sentryDebugIdIdentifier="sentry-dbid-bc27de8f-9be7-4730-a671-77f0da8d662c")}catch{}})();t.Panel=m;t.install=function(e){return e.component(t.name,t),e.component(m.name,m),e};n.useInjectFormItemContext=i;n.ItemRest=r;n.install=function(e){return e.component(n.name,n),e.component(n.Item.name,n.Item),e.component(r.name,r),e};o.Item=s;o.install=function(e){return e.component(o.name,o),e.component(s.name,s),e};
//# sourceMappingURL=index.567ffd31.js.map
