import"./outputWidgets.6bfc0239.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="c8bcf8b2-613f-4cb2-a37f-552759c2d46e",e._sentryDebugIdIdentifier="sentry-dbid-c8bcf8b2-613f-4cb2-a37f-552759c2d46e")}catch{}})();const d=e=>{try{return new URL(e),!0}catch{return!1}};export{d as i};
//# sourceMappingURL=url.c2408bab.js.map
