import{g as f}from"./api.4873ae96.js";import{P as m}from"./Passwordless.43cdb0c3.js";import{a as c}from"./asyncComputed.21831dee.js";import{W as p}from"./WidgetsFrame.f3e18a8a.js";import{d as u,eA as l,eB as _,b as d,ev as y,e as g,u as s,c as b,w as h,ex as w,f as v,v as k}from"./outputWidgets.6bfc0239.js";import"./runnerData.218d57bf.js";import"./url.c2408bab.js";import"./index.d59ef797.js";import"./pubsub.56f48661.js";import"./icons.5f4f8713.js";import"./CircularLoading.c1d47ee0.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="fd0b9091-db0f-46ed-933a-8fe3af43adfe",e._sentryDebugIdIdentifier="sentry-dbid-fd0b9091-db0f-46ed-933a-8fe3af43adfe")}catch{}})();const x={class:"login"},I=u({__name:"Login",setup(e){const t=l(),a=_(),{result:o}=c(f),i=()=>{const{redirect:r,...n}=a.query;if(r){t.push({path:r,query:n,params:a.params});return}t.push({name:"playerKanban",query:n})};return(r,n)=>(d(),y("div",null,[g("div",x,[s(o)?(d(),b(p,{key:0,"main-color":s(o).mainColor,theme:s(o).theme,"font-family":s(o).fontFamily,style:{width:"100vw"}},{default:h(()=>[v(m,{onDone:i})]),_:1},8,["main-color","theme","font-family"])):w("",!0)])]))}});const R=k(I,[["__scopeId","data-v-33714d9d"]]);export{R as default};
//# sourceMappingURL=Login.2f6efab7.js.map
