import{cz as r}from"./outputWidgets.6bfc0239.js";(function(){try{var d=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},e=new Error().stack;e&&(d._sentryDebugIds=d._sentryDebugIds||{},d._sentryDebugIds[e]="d87015cf-1224-48f4-a63d-dba5694d2555",d._sentryDebugIdIdentifier="sentry-dbid-d87015cf-1224-48f4-a63d-dba5694d2555")}catch{}})();const t=(d,e)=>{r.error({message:d,description:e})};export{t as p};
//# sourceMappingURL=popupNotifcation.9ba9d802.js.map
