DOT_ABSTRA_FOLDER_NAME = ".abstra"
CREDENTIALS_FILE = f"{DOT_ABSTRA_FOLDER_NAME}/credentials"
LOCAL_LOGS_FOLDER = f"{DOT_ABSTRA_FOLDER_NAME}/logs"
PERSISTENT_DIR = f"{DOT_ABSTRA_FOLDER_NAME}/persistent"
CACHED_VERSIONS_DIR = f"{DOT_ABSTRA_FOLDER_NAME}/cached_versions"
TEST_DATA_FILE = f"{DOT_ABSTRA_FOLDER_NAME}/test_data.json"
