import{K as n,L as p}from"./repository.03c973cb.js";import{E as a}from"./repository.dc59ddc1.js";import{d as s,b as m,c,u as e}from"./outputWidgets.6bfc0239.js";import{l as d}from"./index.d59ef797.js";import"./asyncComputed.21831dee.js";import"./api.301ca4a6.js";import"./index.cf4c23b9.js";import"./icons.5f4f8713.js";import"./ant-design.bf757549.js";import"./index.71301f31.js";import"./Modal.9595e4e0.js";import"./Text.3be64ce1.js";import"./Base.3f4f4c87.js";import"./Typography.7fe49268.js";import"./index.6bbf489e.js";import"./Link.c1cadb68.js";import"./Paragraph.100fbd75.js";import"./Title.84d6428e.js";import"./index.60dad040.js";import"./index.ecc37a00.js";import"./index.8802c5fa.js";import"./index.567ffd31.js";import"./CollapsePanel.3dd38c7f.js";import"./Form.7d1a8597.js";import"./hasIn.42df2c7d.js";import"./Timeline.049ef2a2.js";import"./index.81e0c92a.js";import"./index.9753d7a2.js";import"./isNumeric.75337b1e.js";import"./contracts.generated.7a08d10a.js";import"./workspaces.aee677ed.js";import"./runnerData.218d57bf.js";import"./url.c2408bab.js";import"./record.dbb754fe.js";import"./pubsub.56f48661.js";import"./scripts.cd1bef2a.js";import"./envVars.75d5e3af.js";import"./ExpandOutlined.3c2528f9.js";import"./Card.77a4a6f5.js";import"./TabPane.e27b42bc.js";(function(){try{var t=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},o=new Error().stack;o&&(t._sentryDebugIds=t._sentryDebugIds||{},t._sentryDebugIds[o]="1aa5ea8e-2c66-4488-8056-9e3747bd68d7",t._sentryDebugIdIdentifier="sentry-dbid-1aa5ea8e-2c66-4488-8056-9e3747bd68d7")}catch{}})();class f{constructor(o=d){this.fetch=o}async fork(o){return(await this.fetch("/_editor/api/stage_runs/fork",{method:"POST",body:JSON.stringify({stage_run_id:o}),headers:{"Content-Type":"application/json"}})).json()}}const to=s({__name:"WorkflowKanban",setup(t){const o=new a,r=new f,i=new p("kanban");return(u,y)=>(m(),c(n,{"kanban-repository":e(o),storage:e(i),"stage-run-repository":e(r)},null,8,["kanban-repository","storage","stage-run-repository"]))}});export{to as default};
//# sourceMappingURL=WorkflowKanban.bf048286.js.map
