import{S as p}from"./Sidebar.7d53bde6.js";import{_ as d}from"./Navbar.vue_vue_type_script_setup_true_lang.53af7a2e.js";import{M as c,N as l,O as u}from"./icons.5f4f8713.js";import{d as b,eB as f,H as g,a as _,b as y,c as v,w as a,f as r}from"./outputWidgets.6bfc0239.js";import{a as w}from"./asyncComputed.21831dee.js";import"./router.979769f7.js";import"./index.76d87691.js";import{O as z}from"./organization.721b781f.js";import{B as h}from"./BaseLayout.b05ffc6b.js";import"./index.ecc37a00.js";import"./logo.084e5d7c.js";import"./Text.3be64ce1.js";import"./Base.3f4f4c87.js";import"./Typography.7fe49268.js";import"./index.a0291250.js";import"./ArrowRightOutlined.08fa31dd.js";import"./Form.7d1a8597.js";import"./hasIn.42df2c7d.js";import"./index.cf4c23b9.js";import"./record.dbb754fe.js";import"./pubsub.56f48661.js";(function(){try{var o=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(o._sentryDebugIds=o._sentryDebugIds||{},o._sentryDebugIds[t]="7ea29db6-1198-4a29-8d6d-c167bf04e1d2",o._sentryDebugIdIdentifier="sentry-dbid-7ea29db6-1198-4a29-8d6d-c167bf04e1d2")}catch{}})();const K=b({__name:"Organization",setup(o){const n=f().params.organizationId,{result:e}=w(()=>z.get(n)),i=g(()=>e.value?[{label:"My organizations",path:"/organizations"},{label:e.value.name,path:`/organizations/${e.value.id}`}]:void 0),s=[{name:"Organization",items:[{name:"Projects",icon:c,path:"projects"},{name:"Editors",icon:l,path:"editors"},{name:"Billing",icon:u,path:"billing"}]}];return(I,B)=>{const m=_("router-view");return y(),v(h,null,{navbar:a(()=>[r(d,{breadcrumb:i.value},null,8,["breadcrumb"])]),sidebar:a(()=>[r(p,{class:"sidebar",sections:s})]),content:a(()=>[r(m)]),_:1})}}});export{K as default};
//# sourceMappingURL=Organization.ddf2d2a6.js.map
