import{V as s}from"./outputWidgets.6bfc0239.js";import{c as i,d as c}from"./index.642f5d72.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},d=new Error().stack;d&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[d]="33b8bd5a-56ea-46a4-adf6-569671d4b10f",e._sentryDebugIdIdentifier="sentry-dbid-33b8bd5a-56ea-46a4-adf6-569671d4b10f")}catch{}})();const{DatePicker:n,WeekPicker:r,MonthPicker:t,YearPicker:f,TimePicker:m,QuarterPicker:a,RangePicker:o}=i(c),y=s(n,{WeekPicker:r,MonthPicker:t,YearPicker:f,RangePicker:o,TimePicker:m,QuarterPicker:a,install:e=>(e.component(n.name,n),e.component(o.name,o),e.component(t.name,t),e.component(r.name,r),e.component(a.name,a),e)});export{y as D,t as M,a as Q,o as R,r as W};
//# sourceMappingURL=dayjs.eef18a40.js.map
