[data-v-393a4c0b]:root{--main-font-family: DM Sans, sans-serif}[data-v-393a4c0b]:root{--abstra-neutral-color: #bbb;--abstra-primary-color: #ffee56;--abstra-dark-text-color: #1b1b23;--abstra-normal-text-color: #414a58;--abstra-main-color-dark: #343b46;--abstra-main-color-light: #ffd84c;--abstra-secondary-color-dark: #4c5767;--abstra-secondary-color-light: #feab4c;--abstra-background-base: #f9fafb;--abstra-main-color-blue: #d14056}.p-dropdown[data-v-393a4c0b]{border-radius:8px;border:1px solid #343b46;background-color:#fff;height:37px;padding:0 10px;align-items:center}.p-dropdown-panel[data-v-393a4c0b]{background-color:#fff;padding:10px}.base-layout[data-v-393a4c0b]{display:flex;flex-direction:column;min-height:100vh}.base-layout.full-canvas[data-v-393a4c0b]{position:relative;overflow:hidden;height:100vh}.base-layout .middle-layout[data-v-393a4c0b]{display:flex;max-width:100vw;box-sizing:border-box;flex-grow:1}.base-layout .middle-layout[data-v-393a4c0b]:not(.full-canvas){height:fit-content}.base-layout .middle-layout:not(.full-canvas) .content-container[data-v-393a4c0b]{flex-grow:1;overflow:hidden}.base-layout .middle-layout:not(.full-canvas) .content-container .content-layout[data-v-393a4c0b]{display:flex;flex-direction:column;width:100%;height:100%;align-items:center}.base-layout .middle-layout:not(.full-canvas) .content-container .content-layout[data-v-393a4c0b]:not(.no-margins){margin-bottom:100px;margin-top:30px}.base-layout .middle-layout:not(.full-canvas) .content-container .content-layout[data-v-393a4c0b]>*{max-width:calc(100% - 20px);width:960px}.base-layout .middle-layout.full-canvas[data-v-393a4c0b]{flex-grow:1}.base-layout .middle-layout.full-canvas .canvas-container[data-v-393a4c0b]{display:flex;flex-direction:column;flex-grow:1}.base-layout .middle-layout.full-canvas .canvas-container .canvas-content[data-v-393a4c0b]{position:relative;overflow:hidden;flex-grow:1}.base-layout .middle-layout.full-canvas .canvas-container .canvas-content .canvas-absolute[data-v-393a4c0b]{position:absolute;top:0;left:0;right:0;bottom:0;overflow:auto}.base-layout .middle-layout .sidebar[data-v-393a4c0b]{position:sticky;top:30px}.base-layout .content-footer[data-v-393a4c0b]{position:fixed;z-index:4;bottom:0;left:0;width:100%}
